@@ -15,7 +15,7 @@ include!("src/app.rs");
 
 fn main() {
     match version_check::is_min_version("1.31") {
-        Some((true, _)) => {}
+        Some(true) => {}
         // rustc version too small or can't figure it out
         _ => {
             writeln!(&mut io::stderr(), "'fd' requires rustc >= 1.31").unwrap();
