@@ -1,4 +1,5 @@
 pub enum ExitCode {
+    Success,
     GeneralError,
     KilledBySigint,
 }
@@ -6,6 +7,7 @@ pub enum ExitCode {
 impl Into<i32> for ExitCode {
     fn into(self) -> i32 {
         match self {
+            ExitCode::Success => 0,
             ExitCode::GeneralError => 1,
             ExitCode::KilledBySigint => 130,
         }
